@@ -158,7 +158,6 @@ class NoEventBusConsumer(EventBusConsumer):
 
 
 def make_single_consumer(*, topic: str, group_id: str,
-                         signal: OpenEdxPublicSignal = None,  # pylint: disable=unused-argument
                          **kwargs) -> EventBusConsumer:
     """
     Construct a consumer for a given topic, group, and signal.
@@ -168,7 +167,6 @@ def make_single_consumer(*, topic: str, group_id: str,
     Arguments:
         topic: The event bus topic to consume from (without any environmental prefix)
         group_id: The consumer group to participate in
-        signal: DEPRECATED This argument will be ignored. Signals will be determined by message headers
     """
     options = {
         'topic': topic,
