@@ -14,7 +14,9 @@ from openedx_events.learning.data import (
     CourseDiscussionConfigurationData,
     CourseEnrollmentData,
     PersistentCourseGradeData,
+    ProgramCertificateData,
     UserData,
+    UserNotificationData,
     XBlockSkillVerificationData,
 )
 from openedx_events.tooling import OpenEdxPublicSignal
@@ -90,6 +92,16 @@ CERTIFICATE_CREATED = OpenEdxPublicSignal(
     }
 )
 
+# .. event_type: org.openedx.learning.program.certificate.awarded.v1
+# .. event_name: PROGRAM_CERTIFICATE_AWARDED
+# .. event_description: Emit when a program certificate is awarded to a learner
+# .. event_data: ProgramCertificateData
+PROGRAM_CERTIFICATE_AWARDED = OpenEdxPublicSignal(
+    event_type="org.openedx.learning.program.certificate.awarded.v1",
+    data={
+        "program_certificate": ProgramCertificateData,
+    }
+)
 
 # .. event_type: org.openedx.learning.certificate.changed.v1
 # .. event_name: CERTIFICATE_CHANGED
@@ -114,6 +126,16 @@ CERTIFICATE_REVOKED = OpenEdxPublicSignal(
     }
 )
 
+# .. event_type: org.openedx.learning.program.certificate.revoked.v1
+# .. event_name: PROGRAM_CERTIFICATE_REVOKED
+# .. event_description: Emit when a program certificate is revoked from a learner
+# .. event_data: ProgramCertificateData
+PROGRAM_CERTIFICATE_REVOKED = OpenEdxPublicSignal(
+    event_type="org.openedx.learning.program.certificate.revoked.v1",
+    data={
+        "program_certificate": ProgramCertificateData,
+    }
+)
 
 # .. event_type: org.openedx.learning.cohort_membership.changed.v1
 # .. event_name: COHORT_MEMBERSHIP_CHANGED
@@ -156,8 +178,21 @@ PERSISTENT_GRADE_SUMMARY_CHANGED = OpenEdxPublicSignal(
 # .. event_description: Fired when an XBlock skill is verified.
 # .. event_data: XBlockSkillVerificationData
 XBLOCK_SKILL_VERIFIED = OpenEdxPublicSignal(
-    event_type="org.openedx.content_authoring.xblock.skill.verified.v1",
+    event_type="org.openedx.learning.xblock.skill.verified.v1",
     data={
         "xblock_info": XBlockSkillVerificationData,
     }
 )
+
+# .. event_type: org.openedx.learning.user.notification.requested.v1
+# .. event_name: USER_NOTIFICATION
+# .. event_description: Can be fired from apps to send user notifications.
+# .. event_data: UserNotificationSendListData
+# Warning: This event is currently incompatible with the event bus, list/dict cannot be serialized yet
+#
+USER_NOTIFICATION_REQUESTED = OpenEdxPublicSignal(
+    event_type="org.openedx.learning.user.notification.requested.v1",
+    data={
+        "notification_data": UserNotificationData,
+    }
+)
